@@ -118,7 +118,7 @@ class GameMode(IntEnum):
 	VANILLA = 3
 	SURVIVOR = 8
 	RACING = 9
-	DEFILENTE = 10
+	DEFILANTE = 10
 	MUSIC = 11
 	SHAMAN = 13
 	VILLAGE = 16
